==> cryptocons-1.0.3.tgz: package/src/components/Cex.tsx <==
import React from 'react'
import { createIcon } from '../createIcon'

export const Cex = createIcon({
    path: (
        <>
            <g clipPath="url(#Cex_a)">
                <path
                    d="M3.22631 8.1355C3.21056 8.17534 3.19573 8.21518 3.18091 8.25595L3.20222 8.24576L3.22631 8.1355Z"
                    fill="black"
                ></path>
                <path
                    d="M12.2778 17.6666H12.4251H12.8995L12.5873 17.1265L12.2778 17.6629V17.6666Z"
                    fill="#19A6F2"
                ></path>
                <path
                    d="M11.8478 19.4697C11.6477 19.4697 11.4494 19.4586 11.2539 19.4391L9.9012 21.7814C10.5395 21.927 11.1922 22.0004 11.8469 22H15.3983L13.9371 19.4697H11.8478Z"
                    fill="#19A6F2"
                ></path>
                <path
                    d="M18.1767 15.3011L12.587 17.1301L12.8992 17.6703H16.1606L16.143 17.6536L18.6771 15.3011H18.1767Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M13.9378 19.4696L15.3989 21.9999H17.3706L18.311 19.4696H13.9378Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M18.8837 17.6702H18.9764L19.0264 17.5358L18.8837 17.6702Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M11.4131 15.0973C10.3068 14.6341 9.51652 13.4388 9.51652 12.0398C9.51652 11.9675 9.51652 11.8953 9.52301 11.8248L8.57517 10.1812L7.96644 15.3271L7.95069 15.4624L8.10356 15.517L12.5833 17.1301L11.4131 15.0973Z"
                    fill="#17B8F3"
                ></path>
                <path
                    d="M8.10732 15.5172C8.595 16.1669 9.22344 16.6978 9.94551 17.0701C10.6676 17.4423 11.4646 17.6463 12.2767 17.6667L12.5871 17.1303L8.10732 15.5172Z"
                    fill="#18C2F2"
                ></path>
                <path
                    d="M8.15662 18.267L8.37343 21.2837C8.86645 21.4959 9.37786 21.6624 9.90127 21.7813L11.254 19.439C10.1361 19.3288 9.06743 18.9244 8.15662 18.267V18.267Z"
                    fill="#18C2F2"
                ></path>
                <path
                    d="M18.1766 15.3011H12.4248C12.0773 15.3009 11.7334 15.2316 11.413 15.0973L12.5869 17.1301L18.1766 15.3011Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M9.52323 11.8211C9.54556 11.4192 9.63643 11.0241 9.79192 10.6528L8.57539 10.1812L9.52323 11.8211Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M11.2935 12.0501C11.2979 12.3851 11.4344 12.7047 11.6734 12.9395C11.9123 13.1743 12.2344 13.3052 12.5693 13.3037H16.5831L11.514 11.3283C11.3683 11.5406 11.2913 11.7926 11.2935 12.0501V12.0501Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M9.79192 10.6557C9.88058 10.4433 9.9908 10.2406 10.1208 10.0507L8.57539 10.1813L9.79192 10.6557Z"
                    fill="#18D1F4"
                ></path>
                <path
                    d="M18.0536 10.7733H12.5583C12.3524 10.775 12.1498 10.8264 11.968 10.9232C11.7862 11.02 11.6305 11.1593 11.5141 11.3293L16.5832 13.3037H19.3804L18.0536 10.7733Z"
                    fill="#18D1F4"
                ></path>
                <path
                    d="M17.3708 21.9999H21.4354V19.4696H18.3112L17.3708 21.9999Z"
                    fill="#19DEF3"
                ></path>
                <path
                    d="M19.0294 17.5361L18.9793 17.6704H21.4355V16.3733L20.9454 15.7525L19.0294 17.5361Z"
                    fill="#19DEF3"
                ></path>
                <path
                    d="M21.4354 16.3768V15.3011L20.9452 15.7561L21.4354 16.3768Z"
                    fill="#19A7F3"
                ></path>
                <path
                    d="M2.55367 13.0728C2.62027 13.7406 2.75057 14.4006 2.94281 15.0436L4.06113 13.0562L2.55367 13.0728V13.0728Z"
                    fill="#19D1F3"
                ></path>
                <path
                    d="M5.25105 13.7909L4.06139 13.0562L2.94308 15.0436C3.2219 15.9771 3.63214 16.8662 4.16146 17.6842L6.35825 16.3972C5.83343 15.6032 5.45819 14.7199 5.25105 13.7909V13.7909Z"
                    fill="#02C1E9"
                ></path>
                <path
                    d="M3.20217 8.24579L3.18086 8.25598C2.72853 9.45235 2.49777 10.7211 2.49986 12.0001C2.49986 12.1122 2.49986 12.2234 2.50542 12.3346L4.06106 13.0563L3.20217 8.24579Z"
                    fill="#18A8F2"
                ></path>
                <path
                    d="M2.50551 12.3344C2.51292 12.5828 2.5296 12.8292 2.55369 13.0757L4.06114 13.059L2.50551 12.3344Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M4.06113 13.0563L5.25079 13.791C5.11808 13.2033 5.05126 12.6026 5.05159 12.0001C5.05216 11.7085 5.06825 11.4172 5.09976 11.1273L3.20224 8.24579L4.06113 13.0563Z"
                    fill="#18C2F3"
                ></path>
                <path
                    d="M7.42523 9.767C7.11601 10.4843 6.95829 11.2577 6.96197 12.0388C6.95379 13.2117 7.30422 14.359 7.96633 15.3271L8.57506 10.1812L7.42523 9.767Z"
                    fill="#18E9F3"
                ></path>
                <path
                    d="M5.09976 11.1273C5.17204 10.4346 5.33463 9.75428 5.58341 9.10375L3.20224 8.24579L5.09976 11.1273Z"
                    fill="#18E9F3"
                ></path>
                <path
                    d="M6.3579 16.3974L4.1611 17.6843C5.17824 19.2743 6.64402 20.527 8.37309 21.2839L8.15628 18.2671C7.44861 17.7579 6.83927 17.1243 6.3579 16.3974V16.3974Z"
                    fill="#19E0F3"
                ></path>
                <path
                    d="M18.6125 8.77563L18.3123 8.5162L18.0436 8.77563H18.6125Z"
                    fill="#19DFF3"
                ></path>
                <path
                    d="M19.3756 13.3037H19.9834L19.7833 10.7733H18.0535L19.3756 13.3037Z"
                    fill="#19DFF3"
                ></path>
                <path
                    d="M20.0271 13.3037L21.4938 12.127L20.0901 10.7733H19.7834L19.9835 13.3037H20.0271Z"
                    fill="#18C3F3"
                ></path>
                <path
                    d="M21.3708 8.77568V7.00323L19.69 7.32381L21.3708 8.77568Z"
                    fill="#18C3F3"
                ></path>
                <path
                    d="M17.8805 4.53034L16.4212 2H15.314L15.0166 4.53034H17.8805Z"
                    fill="#19E0F4"
                ></path>
                <path
                    d="M18.819 6.56772L19.2971 6.98188L19.059 6.56772H18.819Z"
                    fill="#19E0F4"
                ></path>
                <path
                    d="M18.0433 8.77563L18.312 8.5162L16.0605 6.5705H15.4611L16.9185 8.77841L18.0433 8.77563Z"
                    fill="#18F3E8"
                ></path>
                <path
                    d="M21.3706 4.53034V4.005L18.0999 2H16.4211L17.8803 4.53034H21.3706Z"
                    fill="#19F3E7"
                ></path>
                <path
                    d="M21.3704 7.00319V6.56772H19.0587L19.2968 6.98188L19.6897 7.32098L21.3704 7.00319Z"
                    fill="#19F3E7"
                ></path>
                <path
                    d="M21.3705 2H18.0998L21.3705 4.005V2Z"
                    fill="#18CAF2"
                ></path>
                <path
                    d="M9.39692 7.44241C8.52384 8.00477 7.83758 8.81391 7.42527 9.76707L8.57509 10.1812L9.39692 7.44241Z"
                    fill="#18A7F3"
                ></path>
                <path
                    d="M3.20224 8.24564L5.58341 9.1036C6.40709 6.95962 8.11653 5.3243 10.2049 4.74893L10.3958 4.11426L3.20224 8.24564Z"
                    fill="#18A7F3"
                ></path>
                <path
                    d="M13.6453 6.56779H12.4251C11.3526 6.56114 10.301 6.8649 9.39722 7.44244L8.57539 10.1812L13.6453 6.56779Z"
                    fill="#18C9F3"
                ></path>
                <path
                    d="M10.2049 4.75262C10.6585 4.62829 11.1248 4.55617 11.5947 4.53767L10.3902 4.11795L10.1993 4.75262H10.2049Z"
                    fill="#18C9F3"
                ></path>
                <path
                    d="M10.0503 2.1853C9.29461 2.3438 8.56293 2.60047 7.87385 2.94876L10.3959 4.11804L10.0503 2.1853Z"
                    fill="#18F3E6"
                ></path>
                <path
                    d="M10.3958 4.11804L7.87378 2.94876C5.79002 4.00037 4.1232 5.85435 3.22633 8.13546L3.20224 8.24571L10.3958 4.11804Z"
                    fill="#009FDC"
                ></path>
                <path
                    d="M11.5955 4.53776C11.6789 4.53776 11.7632 4.53034 11.8475 4.53034H13.9109L11.7919 2C11.2066 2.0032 10.623 2.06528 10.0501 2.18531L10.3956 4.11711L11.6001 4.53683L11.5955 4.53776Z"
                    fill="#17E6F2"
                ></path>
                <path
                    d="M15.0166 4.53034L15.314 2H11.7932L13.9122 4.52942L15.0166 4.53034Z"
                    fill="#18CFF2"
                ></path>
                <path
                    d="M10.1208 10.0505C10.6536 9.27596 11.4875 8.77563 12.4251 8.77563H16.9188L15.4613 6.56772H13.6454L8.57539 10.1812L10.1208 10.0505Z"
                    fill="#17E7F2"
                ></path>
            </g>
            <defs>
                <clipPath id="Cex_a">
                    <rect
                        width="18.9929"
                        height="20"
                        fill="white"
                        transform="translate(2.5 2)"
                    ></rect>
                </clipPath>
            </defs>
        </>
    ),
})

==> cryptocons-1.3.2.tgz: package/src/components/Cex.tsx <==
import React from 'react'
import { createIcon } from '../createIcon'

export const Cex = createIcon({
    path: (
        <>
            <g clipPath="url(#Cex_a)">
                <path
                    d="M3.22631 8.1355C3.21056 8.17534 3.19573 8.21518 3.18091 8.25595L3.20222 8.24576L3.22631 8.1355Z"
                    fill="black"
                ></path>
                <path
                    d="M12.2778 17.6666H12.4251H12.8995L12.5873 17.1265L12.2778 17.6629V17.6666Z"
                    fill="#19A6F2"
                ></path>
                <path
                    d="M11.8478 19.4697C11.6477 19.4697 11.4494 19.4586 11.2539 19.4391L9.9012 21.7814C10.5395 21.927 11.1922 22.0004 11.8469 22H15.3983L13.9371 19.4697H11.8478Z"
                    fill="#19A6F2"
                ></path>
                <path
                    d="M18.1767 15.3011L12.587 17.1301L12.8992 17.6703H16.1606L16.143 17.6536L18.6771 15.3011H18.1767Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M13.9378 19.4696L15.3989 21.9999H17.3706L18.311 19.4696H13.9378Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M18.8837 17.6702H18.9764L19.0264 17.5358L18.8837 17.6702Z"
                    fill="#18C1F3"
                ></path>
                <path
                    d="M11.4131 15.0973C10.3068 14.6341 9.51652 13.4388 9.51652 12.0398C9.51652 11.9675 9.51652 11.8953 9.52301 11.8248L8.57517 10.1812L7.96644 15.3271L7.95069 15.4624L8.10356 15.517L12.5833 17.1301L11.4131 15.0973Z"
                    fill="#17B8F3"
                ></path>
                <path
                    d="M8.10732 15.5172C8.595 16.1669 9.22344 16.6978 9.94551 17.0701C10.6676 17.4423 11.4646 17.6463 12.2767 17.6667L12.5871 17.1303L8.10732 15.5172Z"
                    fill="#18C2F2"
                ></path>
                <path
                    d="M8.15662 18.267L8.37343 21.2837C8.86645 21.4959 9.37786 21.6624 9.90127 21.7813L11.254 19.439C10.1361 19.3288 9.06743 18.9244 8.15662 18.267Z"
                    fill="#18C2F2"
                ></path>
                <path
                    d="M18.1766 15.3011H12.4248C12.0773 15.3009 11.7334 15.2316 11.413 15.0973L12.5869 17.1301L18.1766 15.3011Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M9.52323 11.8211C9.54556 11.4192 9.63643 11.0241 9.79192 10.6528L8.57539 10.1812L9.52323 11.8211Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M11.2935 12.0501C11.2979 12.3851 11.4344 12.7047 11.6734 12.9395C11.9123 13.1743 12.2344 13.3052 12.5693 13.3037H16.5831L11.514 11.3283C11.3683 11.5406 11.2913 11.7926 11.2935 12.0501Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M9.79192 10.6557C9.88058 10.4433 9.9908 10.2406 10.1208 10.0507L8.57539 10.1813L9.79192 10.6557Z"
                    fill="#18D1F4"
                ></path>
                <path
                    d="M18.0536 10.7733H12.5583C12.3524 10.775 12.1498 10.8264 11.968 10.9232C11.7862 11.02 11.6305 11.1593 11.5141 11.3293L16.5832 13.3037H19.3804L18.0536 10.7733Z"
                    fill="#18D1F4"
                ></path>
                <path
                    d="M17.3708 21.9999H21.4354V19.4696H18.3112L17.3708 21.9999Z"
                    fill="#19DEF3"
                ></path>
                <path
                    d="M19.0294 17.5361L18.9793 17.6704H21.4355V16.3733L20.9454 15.7525L19.0294 17.5361Z"
                    fill="#19DEF3"
                ></path>
                <path
                    d="M21.4354 16.3768V15.3011L20.9452 15.7561L21.4354 16.3768Z"
                    fill="#19A7F3"
                ></path>
                <path
                    d="M2.55367 13.0728C2.62027 13.7406 2.75057 14.4006 2.94281 15.0436L4.06113 13.0562L2.55367 13.0728Z"
                    fill="#19D1F3"
                ></path>
                <path
                    d="M5.25105 13.7909L4.06139 13.0562L2.94307 15.0436C3.2219 15.9771 3.63214 16.8662 4.16146 17.6842L6.35825 16.3972C5.83343 15.6032 5.45819 14.7199 5.25105 13.7909Z"
                    fill="#02C1E9"
                ></path>
                <path
                    d="M3.20217 8.24579L3.18086 8.25598C2.72853 9.45235 2.49777 10.7211 2.49986 12.0001C2.49986 12.1122 2.49986 12.2234 2.50542 12.3346L4.06106 13.0563L3.20217 8.24579Z"
                    fill="#18A8F2"
                ></path>
                <path
                    d="M2.5055 12.3344C2.51292 12.5828 2.52959 12.8292 2.55368 13.0757L4.06114 13.059L2.5055 12.3344Z"
                    fill="#18F2F2"
                ></path>
                <path
                    d="M4.06113 13.0563L5.25079 13.791C5.11808 13.2033 5.05126 12.6026 5.05158 12.0001C5.05216 11.7085 5.06824 11.4172 5.09976 11.1273L3.20224 8.24579L4.06113 13.0563Z"
                    fill="#18C2F3"
                ></path>
                <path
                    d="M7.42523 9.767C7.11601 10.4843 6.95829 11.2577 6.96197 12.0388C6.95379 13.2117 7.30422 14.359 7.96633 15.3271L8.57506 10.1812L7.42523 9.767Z"
                    fill="#18E9F3"
                ></path>
                <path
                    d="M5.09976 11.1273C5.17203 10.4346 5.33463 9.75428 5.58341 9.10375L3.20224 8.24579L5.09976 11.1273Z"
                    fill="#18E9F3"
                ></path>
                <path
                    d="M6.35789 16.3974L4.1611 17.6843C5.17824 19.2743 6.64402 20.527 8.37309 21.2839L8.15628 18.2671C7.44861 17.7579 6.83927 17.1243 6.35789 16.3974Z"
                    fill="#19E0F3"
                ></path>
                <path
                    d="M18.6125 8.77563L18.3123 8.5162L18.0436 8.77563H18.6125Z"
                    fill="#19DFF3"
                ></path>
                <path
                    d="M19.3756 13.3037H19.9834L19.7833 10.7733H18.0535L19.3756 13.3037Z"
                    fill="#19DFF3"
                ></path>
                <path
                    d="M20.0271 13.3037L21.4938 12.127L20.0901 10.7733H19.7834L19.9835 13.3037H20.0271Z"
                    fill="#18C3F3"
                ></path>
                <path
                    d="M21.3708 8.77568V7.00323L19.69 7.32381L21.3708 8.77568Z"
                    fill="#18C3F3"
                ></path>
                <path
                    d="M17.8805 4.53034L16.4212 2H15.314L15.0166 4.53034H17.8805Z"
                    fill="#19E0F4"
                ></path>
                <path
                    d="M18.819 6.56772L19.2971 6.98188L19.059 6.56772H18.819Z"
                    fill="#19E0F4"
                ></path>
                <path
                    d="M18.0433 8.77563L18.312 8.5162L16.0605 6.5705H15.4611L16.9185 8.77841L18.0433 8.77563Z"
                    fill="#18F3E8"
                ></path>
                <path
                    d="M21.3706 4.53034V4.005L18.0999 2H16.4211L17.8803 4.53034H21.3706Z"
                    fill="#19F3E7"
                ></path>
                <path
                    d="M21.3704 7.00319V6.56772H19.0587L19.2968 6.98188L19.6896 7.32098L21.3704 7.00319Z"
                    fill="#19F3E7"
                ></path>
                <path
                    d="M21.3705 2H18.0998L21.3705 4.005V2Z"
                    fill="#18CAF2"
                ></path>
                <path
                    d="M9.39692 7.44241C8.52384 8.00477 7.83758 8.81391 7.42527 9.76707L8.57509 10.1812L9.39692 7.44241Z"
                    fill="#18A7F3"
                ></path>
                <path
                    d="M3.20224 8.24564L5.58341 9.1036C6.40709 6.95962 8.11653 5.3243 10.2049 4.74893L10.3958 4.11426L3.20224 8.24564Z"
                    fill="#18A7F3"
                ></path>
                <path
                    d="M13.6453 6.56779H12.4251C11.3526 6.56114 10.301 6.8649 9.39722 7.44244L8.57539 10.1812L13.6453 6.56779Z"
                    fill="#18C9F3"
                ></path>
                <path
                    d="M10.2049 4.75262C10.6585 4.62829 11.1248 4.55617 11.5947 4.53767L10.3902 4.11795L10.1993 4.75262H10.2049Z"
                    fill="#18C9F3"
                ></path>
                <path
                    d="M10.0503 2.1853C9.29461 2.3438 8.56293 2.60047 7.87386 2.94876L10.3959 4.11804L10.0503 2.1853Z"
                    fill="#18F3E6"
                ></path>
                <path
                    d="M10.3958 4.11804L7.87378 2.94876C5.79002 4.00037 4.1232 5.85435 3.22633 8.13546L3.20224 8.24571L10.3958 4.11804Z"
                    fill="#009FDC"
                ></path>
                <path
                    d="M11.5955 4.53776C11.6789 4.53776 11.7632 4.53034 11.8475 4.53034H13.9109L11.7919 2C11.2066 2.0032 10.623 2.06528 10.05 2.18531L10.3956 4.11711L11.6001 4.53683L11.5955 4.53776Z"
                    fill="#17E6F2"
                ></path>
                <path
                    d="M15.0166 4.53034L15.314 2H11.7932L13.9122 4.52942L15.0166 4.53034Z"
                    fill="#18CFF2"
                ></path>
                <path
                    d="M10.1208 10.0505C10.6536 9.27596 11.4875 8.77563 12.4251 8.77563H16.9188L15.4613 6.56772H13.6454L8.57539 10.1812L10.1208 10.0505Z"
                    fill="#17E7F2"
                ></path>
            </g>
            <defs>
                <clipPath id="Cex_a">
                    <rect
                        width="18.9929"
                        height="20"
                        fill="white"
                        transform="translate(2.5 2)"
                    ></rect>
                </clipPath>
            </defs>
        </>
    ),
})
